import Link from "next/link";
import React from "react";
import { useCartDataQuery } from "../../app/features/cart/apiSlice";
import useAuthCheck from "../../hooks/AuthCheck";
import { useDispatch } from "react-redux";
import { authModalSet } from "../../app/features/auth/authSlice";

function MBottomMenu() {
  const { data: cartData } = useCartDataQuery();
  const userInfo = useAuthCheck();
  const dispatch = useDispatch();
  const openLoginModal = () => {
    dispatch(authModalSet("login"));
  };
  return (
    <div className="sm:hidden w-full fixed bottom-0 py-4 bg-white mb-nav rounded-t-[20px] z-50 px-5 flex justify-between">
      <Link href="/" className="">
        <p className="flex flex-col items-center text-sm gap-1.5 text-[#65656C] hover:text-[#8037A9] cursor-pointer">
          <svg
            width="23"
            height="24"
            viewBox="0 0 23 24"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              d="M21.9745 23.91H14.5032C13.966 23.91 13.5265 23.4705 13.5265 22.9334V18.2943C13.5265 17.1223 12.5987 16.1945 11.4268 16.1945C10.2548 16.1945 9.32696 17.1223 9.32696 18.2943V22.9334C9.32696 23.4705 8.88747 23.91 8.35032 23.91H0.976645C0.43949 23.91 0 23.4705 0 22.9334V10.4323C0 9.55334 0.43949 8.72319 1.12314 8.23487L10.9384 1.15419C11.2803 0.910029 11.7197 0.910029 12.0616 1.15419L21.8769 8.23487C22.5605 8.72319 23 9.55334 23 10.4323V22.9822C22.9512 23.4705 22.5117 23.91 21.9745 23.91ZM15.4798 22.0056H21.0467V10.4323C21.0467 10.1882 20.9002 9.944 20.7049 9.7975L11.4756 3.10748L2.24628 9.74867C2.05096 9.89517 1.90446 10.1393 1.90446 10.3835V21.9567H7.47134V18.2943C7.47134 16.0969 9.27813 14.2901 11.4756 14.2901C13.673 14.2901 15.4798 16.0969 15.4798 18.2943V22.0056Z"
              fill="currentColor"
            />
          </svg>
          <span className="">Home</span>
        </p>
      </Link>
      <Link href="/cart" passHref>
        <a className="flex flex-col items-center text-sm gap-1.5 text-[#65656C] hover:text-[#8037A9] cursor-pointer relative">
          <svg
            width="24"
            height="24"
            viewBox="0 0 24 24"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              d="M9 14L9 18"
              stroke="currentColor"
              stroke-width="1.5"
              stroke-linecap="round"
              stroke-linejoin="round"
            ></path>
            <path
              d="M15 14L15 18"
              stroke="currentColor"
              stroke-width="1.5"
              stroke-linecap="round"
              stroke-linejoin="round"
            ></path>
            <path
              d="M6 6V4C6 2.89543 6.89543 2 8 2H16C17.1046 2 18 2.89543 18 4V6"
              stroke="currentColor"
              stroke-width="1.5"
              stroke-linecap="round"
              stroke-linejoin="round"
            ></path>
            <path
              d="M2.58683 10H21.4132M18.0351 6L5.96486 6C3.45403 6 1.57594 8.32624 2.08312 10.808L3.71804 18.808C4.09787 20.6666 5.71942 22 7.59978 22H16.4002C18.2806 22 19.9021 20.6666 20.282 18.808L21.9169 10.808C22.4241 8.32624 20.546 6 18.0351 6Z"
              stroke="currentColor"
              stroke-width="1.5"
              stroke-linecap="round"
              stroke-linejoin="round"
            ></path>
          </svg>

          <span className="absolute -top-1 -right-1 bg-secondary w-4 h-4 rounded-full inline-flex items-center justify-center font-medium text-xs text-dark-300">
            {cartData?.cartProducts?.reduce(
              (total, product) => total + product.products.length,
              0
            ) || 0}
          </span>
          <span className="">Cart</span>
        </a>
      </Link>
      <Link href="/categories" className="">
        <p className="flex flex-col items-center text-sm gap-1.5 text-[#65656C] hover:text-[#8037A9] cursor-pointer">
          <svg
            width="24"
            height="24"
            viewBox="0 0 24 24"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              d="M20.7375 23.25H15.6375C14.25 23.25 13.125 22.125 13.125 20.7375V13.875C13.125 13.4625 13.4625 13.125 13.875 13.125H20.7375C22.125 13.125 23.25 14.25 23.25 15.6375V20.7375C23.25 22.125 22.125 23.25 20.7375 23.25ZM14.625 14.625V20.7375C14.625 21.3 15.075 21.75 15.6375 21.75H20.7375C21.3 21.75 21.75 21.3 21.75 20.7375V15.6375C21.75 15.075 21.3 14.625 20.7375 14.625H14.625Z"
              fill="currentColor"
            />
            <path
              d="M8.3625 23.25H3.2625C1.875 23.25 0.75 22.125 0.75 20.7375V15.6375C0.75 14.25 1.875 13.125 3.2625 13.125H10.125C10.5375 13.125 10.875 13.4625 10.875 13.875V20.7375C10.875 22.125 9.75 23.25 8.3625 23.25ZM3.2625 14.625C2.7 14.625 2.25 15.075 2.25 15.6375V20.7375C2.25 21.3 2.7 21.75 3.2625 21.75H8.3625C8.925 21.75 9.375 21.3 9.375 20.7375V14.625H3.2625Z"
              fill="currentColor"
            />
            <path
              d="M20.7375 10.875H13.875C13.4625 10.875 13.125 10.5375 13.125 10.125V3.2625C13.125 1.875 14.25 0.75 15.6375 0.75H20.7375C22.125 0.75 23.25 1.875 23.25 3.2625V8.3625C23.25 9.75 22.125 10.875 20.7375 10.875ZM14.625 9.375H20.7375C21.3 9.375 21.75 8.925 21.75 8.3625V3.2625C21.75 2.7 21.3 2.25 20.7375 2.25H15.6375C15.075 2.25 14.625 2.7 14.625 3.2625V9.375Z"
              fill="currentColor"
            />
            <path
              d="M10.125 10.875H3.2625C1.875 10.875 0.75 9.75 0.75 8.3625V3.2625C0.75 1.875 1.875 0.75 3.2625 0.75H8.3625C9.75 0.75 10.875 1.875 10.875 3.2625V10.125C10.875 10.5375 10.5375 10.875 10.125 10.875ZM3.2625 2.25C2.7 2.25 2.25 2.7 2.25 3.2625V8.3625C2.25 8.925 2.7 9.375 3.2625 9.375H9.375V3.2625C9.375 2.7 8.925 2.25 8.3625 2.25H3.2625Z"
              fill="currentColor"
            />
          </svg>

          <span className="">Category</span>
        </p>
      </Link>
      {!!userInfo?.accessToken ? (
        <Link href="/user-dashboard" className="">
          <p className="flex flex-col items-center text-sm gap-1.5 text-[#65656C] hover:text-[#8037A9] cursor-pointer">
            <svg
              width="23"
              height="23"
              viewBox="0 0 23 23"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                d="M19.6317 3.36826C17.4597 1.19622 14.5717 0 11.5 0C8.42829 0 5.54031 1.19622 3.36826 3.36826C1.19622 5.54031 0 8.42829 0 11.5C0 14.5717 1.19622 17.4597 3.36826 19.6317C5.54031 21.8038 8.42829 23 11.5 23C14.5717 23 17.4597 21.8038 19.6317 19.6317C21.8038 17.4597 23 14.5717 23 11.5C23 8.42829 21.8038 5.54031 19.6317 3.36826ZM4.99107 19.2848C5.3708 16.0175 8.17999 13.4948 11.5 13.4948C13.2502 13.4948 14.896 14.1767 16.134 15.4145C17.1798 16.4605 17.8394 17.8263 18.0091 19.2846C16.2456 20.7616 13.9749 21.6523 11.5 21.6523C9.02509 21.6523 6.7546 20.7618 4.99107 19.2848ZM11.5 12.1068C9.57415 12.1068 8.00715 10.5398 8.00715 8.61395C8.00715 6.68792 9.57415 5.12109 11.5 5.12109C13.4258 5.12109 14.9929 6.68792 14.9929 8.61395C14.9929 10.5398 13.4258 12.1068 11.5 12.1068ZM19.169 18.1455C18.8256 16.7609 18.1095 15.4844 17.0868 14.4617C16.2586 13.6334 15.2787 13.0121 14.2101 12.6227C15.4947 11.7515 16.3405 10.2796 16.3405 8.61395C16.3405 5.94495 14.169 3.77344 11.5 3.77344C8.83101 3.77344 6.65949 5.94495 6.65949 8.61395C6.65949 10.2804 7.50599 11.7529 8.7917 12.6239C7.80851 12.9822 6.89867 13.5362 6.11587 14.2655C4.98229 15.3212 4.19511 16.6672 3.83012 18.1444C2.28435 16.3624 1.34766 14.0386 1.34766 11.5C1.34766 5.90196 5.90196 1.34766 11.5 1.34766C17.098 1.34766 21.6523 5.90196 21.6523 11.5C21.6523 14.0391 20.7153 16.3635 19.169 18.1455Z"
                fill="currentColor"
              />
            </svg>
            <span className="">Profile</span>
          </p>
        </Link>
      ) : (
        <div onClick={openLoginModal} className="">
          <p className="flex flex-col items-center text-sm gap-1.5 text-[#65656C] hover:text-[#8037A9] cursor-pointer">
            <svg
              width="23"
              height="23"
              viewBox="0 0 23 23"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                d="M19.6317 3.36826C17.4597 1.19622 14.5717 0 11.5 0C8.42829 0 5.54031 1.19622 3.36826 3.36826C1.19622 5.54031 0 8.42829 0 11.5C0 14.5717 1.19622 17.4597 3.36826 19.6317C5.54031 21.8038 8.42829 23 11.5 23C14.5717 23 17.4597 21.8038 19.6317 19.6317C21.8038 17.4597 23 14.5717 23 11.5C23 8.42829 21.8038 5.54031 19.6317 3.36826ZM4.99107 19.2848C5.3708 16.0175 8.17999 13.4948 11.5 13.4948C13.2502 13.4948 14.896 14.1767 16.134 15.4145C17.1798 16.4605 17.8394 17.8263 18.0091 19.2846C16.2456 20.7616 13.9749 21.6523 11.5 21.6523C9.02509 21.6523 6.7546 20.7618 4.99107 19.2848ZM11.5 12.1068C9.57415 12.1068 8.00715 10.5398 8.00715 8.61395C8.00715 6.68792 9.57415 5.12109 11.5 5.12109C13.4258 5.12109 14.9929 6.68792 14.9929 8.61395C14.9929 10.5398 13.4258 12.1068 11.5 12.1068ZM19.169 18.1455C18.8256 16.7609 18.1095 15.4844 17.0868 14.4617C16.2586 13.6334 15.2787 13.0121 14.2101 12.6227C15.4947 11.7515 16.3405 10.2796 16.3405 8.61395C16.3405 5.94495 14.169 3.77344 11.5 3.77344C8.83101 3.77344 6.65949 5.94495 6.65949 8.61395C6.65949 10.2804 7.50599 11.7529 8.7917 12.6239C7.80851 12.9822 6.89867 13.5362 6.11587 14.2655C4.98229 15.3212 4.19511 16.6672 3.83012 18.1444C2.28435 16.3624 1.34766 14.0386 1.34766 11.5C1.34766 5.90196 5.90196 1.34766 11.5 1.34766C17.098 1.34766 21.6523 5.90196 21.6523 11.5C21.6523 14.0391 20.7153 16.3635 19.169 18.1455Z"
                fill="currentColor"
              />
            </svg>
            <span className="">Profile</span>
          </p>
        </div>
      )}
    </div>
  );
}

export default MBottomMenu;
